@@ -15,6 +15,8 @@ c
        real*8  t, tkgpm2, cxai, den, cvh2den, eg
        real*8  prob, u, cmPairMFP
        real*8 xaimin/0.1/
+       logical first/.true./
+       save first
 c     
        eg = TrackBefMove.p.fm.p(4)
        if(LpmEffect .and. eg .gt. LpmPairEmin) then
@@ -36,8 +38,12 @@ c          den = cthick2den(TrackBefMove.pos.depth)
           call csetIntInf(t*X0, .false., 'photoe')
        endif
        if( eg .gt. MinPhotoProdE .and. PhotoProd ) then
-          call cghPath(eg,    tkgpm2)
-          call csetIntInf(tkgpm2, .false., 'photop')
+         if(first) then
+            call cixsec
+            first=.false.
+         endif
+         call cghPath(eg,    tkgpm2)
+         call csetIntInf(tkgpm2, .false., 'photop')
        endif
        if(MagPair .eq. 1 .and. eg .gt.  MagPairEmin) then
           Xai = cxai(TrackBefMove.p, Mag)
