@@ -21,7 +21,6 @@ c      ***  do until no more ptcl in stack
       do while (.true.)
 c           get one particle from stack
          call cpop(TrackBefMove, moreptcl)
-
          if(moreptcl .eq. 0) goto 100   !  exit
          call rndsw(jold, 1)            !  specify 1st generator.
          call cifDead(TrackBefMove, icon)  ! generator may be switched to 2
@@ -110,9 +109,7 @@ c           In that case, MoveStat == Truncated.
 #if DEBUG == 1
       call checkstat('before csampIntl')
 #endif
-
       call csampIntL
-
 #if DEBUG == 1
       call checkstat('after csampIntl')
 #endif
@@ -158,14 +155,26 @@ c           see if truncation is really ok.  for energy = 0,
 c           if anti ptcl, it should be anihilated, if decayabl,
 c           it should be decayed.
          if(MovedTrack.p.fm.p(4) .eq. MovedTrack.p.mass) then
-            if(MovedTrack.p.subcode .eq. antip) then
+            if(MovedTrack.p.code .eq. kelec .and. 
+     *              MovedTrack.p.charge .eq. 1) then
                MoveStat = ToInteract
+c                   force to anihilate
+               IntInfArray(ProcessNo).process = 'anihi'
+            elseif(MovedTrack.p.code .eq. knuc .and. 
+     *                     MovedTrack.p.subcode .eq. antip ) then
+c                anti protorn/neutron anhilation
+               MoveStat = ToInteract
+               IntInfArray(ProcessNo).process = 'coll'
             elseif(MovedTrack.p.code .eq. kmuon) then
                MoveStat = ToInteract
+c                  force to decay; interaction fixed so far might be knock-on 
+               IntInfArray(ProcessNo).process = 'decay'
             elseif(MovedTrack.p.code .eq. kpion) then
                MoveStat = ToInteract
+               IntInfArray(ProcessNo).process = 'decay'
             elseif(MovedTrack.p.code .eq. kkaon) then
                MoveStat = ToInteract
+               IntInfArray(ProcessNo).process = 'decay'
             endif
          endif
       endif 
@@ -181,7 +190,7 @@ c                       This should be recorded
          endif
 c        &&&&&&&&&&&&
 c              stack current ptcl
-         call cpush(MovedTrack)
+            call cpush(MovedTrack)
       elseif(MoveStat .eq. ToInteract ) then
          if(Zfirst.pos.depth .eq. 0.) then
 c            if(  (MovedTrack.p.code .ge. kpion  .and. 
@@ -239,6 +248,7 @@ c                  or some may loose energy by dE/dx etc.
 c                in this case, even E> KEminObs must be recorded
 c                 for skeleton making for kahanshin
 c                  where should be +1 at flesh time
+
                MovedTrack.where = MovedTrack.where + 1
                never = -3
                call chookEInt(never)
